@@ -1,23 +1,9 @@
 -- 
 -- Created by SQL::Translator::Producer::MySQL
--- Created on Thu Jul  6 22:57:31 2017
+-- Created on Thu May 11 17:10:18 2017
 -- 
 SET foreign_key_checks=0;
 
-DROP TABLE IF EXISTS `metabase_user`;
-
---
--- Table: `metabase_user`
---
-CREATE TABLE `metabase_user` (
-  `id` integer NOT NULL auto_increment,
-  `resource` char(50) NOT NULL,
-  `fullname` varchar(255) NOT NULL,
-  `email` varchar(255) NULL,
-  PRIMARY KEY (`id`),
-  UNIQUE `metabase_user_resource` (`resource`)
-);
-
 DROP TABLE IF EXISTS `test_report`;
 
 --
@@ -25,7 +11,6 @@ DROP TABLE IF EXISTS `test_report`;
 --
 CREATE TABLE `test_report` (
   `id` char(36) NOT NULL,
-  `created` datetime NOT NULL,
   `report` JSON NOT NULL,
   PRIMARY KEY (`id`)
 );
